import Vue from 'vue';
import Vuex from 'vuex';
import _ from 'lodash';

Vue.use(Vuex);
const api = {
  fairs: '/jobs/fairs',
};

export const state = () => ({
  limit: 5,
  rows: 0,
  totalRow: 20,
  loading: false,
  isHasMore: true,
});

export const mutations = {
  updateTotalRow(state, payload) {
    state.totalRow = payload;
  },
  updateRows(state, payload) {
    state.rows = payload;
  },
  updateLoading(state, payload) {
    state.loading = payload;
  },
  updateHasMore(state, payload) {
    state.isHasMore = payload;
  },
};

export const actions = {
  /**
   * 请求列表
   * payload => type:请求什么列表:jobfair/talk/jobinfo/jobs
   */
  async fairsOperation({ state }, { type, data }) {
    let result;
    if (type === 'add') {
      let { info, corpid, corpname } = data;
      result = await this.$axios.$post(api.talks, info, {}, { corpid: corpid, corpname: corpname });
    }
    if (type === 'list') {
      let { corpid } = data;
      result = await this.$axios.$get(api.fairs, {}, { corpid: corpid });
    }
    if (type === 'search') {
      let { id } = data;
      result = await this.$axios.$get(api.profilesinfo, { id: id });
    }
    if (type === 'update') {
      let { info, id } = data;
      result = await this.$axios.$post(api.profilesinfo, info, { id: id });
    }
    if (type === 'delete') {
      let { id } = data;
      result = await this.$axios.$delete(api.profilesinfo, {}, { id: id });
    }
    return result;
  },
  async getList({ state, commit }, payload) {
    let result = [];
    if (!payload) {
      let item = _.get(data, 'list');
      result = [item, item, item, item, item];
    } else {
      let item = _.get(data, `${payload}List`);
      result = [item, item, item, item, item, item, item];
    }
    commit('updateRows', state.rows + result.length);
    commit(`updateLoading`, false);
    commit('updateHasMore', state.totalRow > state.rows);
    return result;
  },
  async talkList({ state, commit }, payload) {
    let talkList = _.get(data, `talkList`);
    let result = [talkList, talkList, talkList, talkList, talkList];
    console.log(data.talkList);
    commit('updateRows', state.rows + result.length);
    commit(`updateLoading`, false);
    return result;
  },
  async getJobList({ state, commit }, payload) {
    let result = [];
    let item = _.get(data, `${payload}List`);
    result = [item, item, item, item, item];
    let itemList = { result: result, totalRow: payload === 'jobs' ? 30 : 20 };
    commit(`updateLoading`, false);
    return itemList;
  },
};

const data = {
  list: {
    fair_id: '1',
    title: 'title',
    organisers: '主办方',
    address: 'address',
    fact_c_count: '2000',
    meet_day: '2019-07-01',
    meet_time: '19:00',
    view_count: '1000',
    is_over: '0',
  },
  talkList: {
    career_talk_id: '1',
    logo: '',
    company_name: '辽宁鸿文教育科技有限公司',
    school_name: '长春大学',
    address: 'address',
    meet_day: '2019-05-03',
    meet_time: '13:00',
    view_count: '2019',
    is_yun: '1',
  },
  jobsList: {
    is_intern: '0',
    about_major: '专业',
    city_name: '城市',
    create_time: '2019-08-09',
    degree_require: '岗位需求',
    job_name: '职位名称',
    job_number: '3',
    publish_id: 1,
    salary: '3k-5k',
    tags: [
      { name: '标签1' },
      { name: '标签22' },
      { name: '标签333' },
      { name: '标签4444' },
      { name: '标签55555' },
      { name: '标签666666' },
      { name: '标签7' },
      { name: '标签8' },
      { name: '标签9' },
    ],
  },
  internList: {
    is_intern: '1',
    about_major: '专业',
    city_name: '城市',
    create_time: '2019-08-09',
    degree_require: '岗位需求',
    job_name: '职位名称',
    job_number: '3',
    publish_id: 1,
    salary: '3k-5k',
    tags: [
      { name: '标签1' },
      { name: '标签22' },
      { name: '标签333' },
      { name: '标签4444' },
      { name: '标签55555' },
      { name: '标签666666' },
      { name: '标签7' },
      { name: '标签8' },
      { name: '标签9' },
    ],
  },
  jobinfoList: {
    company_id: '1',
    content: '公司介绍北京骏嘉财通科技有限公司（弘历软件）',
    create_time: '2019-07-01',
    logo_url: 'http://yun-campus-res.oss-cn-shenzhen.aliyuncs.com/company/1552618371-9762.png',
    recruit_type: '实习招聘',
    recruitment_id: '627677',
    recruitment_num: '11',
    title: '弘历软件金融管培生招聘简章',
    type: '0',
    view_count: '24',
  },
};
